<?php
/*
 * Created by Pixel-Mafia
 * www.pixel-mafia.com
*/

# General
add_theme_support('title-tag');
add_theme_support('post-thumbnails');
add_theme_support('automatic-feed-links');
add_theme_support('post-formats', array('image', 'video', 'audio', 'quote'));

if (!isset($content_width)) {
    $content_width = 1130;
}

# Custom get_theme_mod
function liza_get_theme_mod($name) {
	if (func_num_args() > 1) {
		die ('The liza_get_theme_mod("'.esc_attr($name).'") function takes only one argument. Define default values in core/customizer.php.');
	}
	
	global $liza_customizer_default_values;
	
	if (!isset($liza_customizer_default_values[$name])) {
		die ('Error! You did not add the default value for the "'.esc_attr($name).'" option! core/customizer.php.');
	}
	return get_theme_mod($name, $liza_customizer_default_values[$name]);
}

# ADD Localization Folder
add_action('after_setup_theme', 'liza_pomo');
function liza_pomo()
{
    load_theme_textdomain('liza', get_template_directory() . '/languages');
}

require_once(get_template_directory() . "/core/init.php");

# Admin Ajax
add_action('admin_head', 'liza_admin_ajax_url');
function liza_admin_ajax_url() {
    echo "
    <script>
        var liza_admin_ajax_url = '" . admin_url("admin-ajax.php") . "';
    </script>
    ";
}

# ADD Theme Settings Page
add_action('admin_menu', 'liza_add_menu');
function liza_add_menu()
{
    add_theme_page('Liza', 'Liza', 'administrator', 'liza_settings_page', 'liza_theme_settings_page' );
}

# Show Admin Settings Page
function liza_theme_settings_page()
{
    if (!current_user_can('manage_options')) {
        wp_die(esc_html__('You do not have permissions to access this page.', 'liza'));
    }
	echo '
    <div class="liza_admin_wrapper">
    	<h1>Hey!</h1>
	    <p>All settings of our theme are made through a standard Customizer. Click <a href="'.get_admin_url(null, 'customize.php').'">here</a> to go to the settings.</p>
	
		<p>If you want to reset all settings, feel free to click on <a href="#" class="liza_reset_all_settings">this link</a>. But remember that there is no turning back ;)</p>
	
		<p>If you have any questions, problems or want to talk - email us via the form on <a href="http://themeforest.net/user/pixel-mafia" target="_blank">this</a> page.</p>
    </div>
    ';
}

# Register CSS/JS
add_action('wp_enqueue_scripts', 'liza_css_js');
if (!function_exists('liza_css_js')) {
    function liza_css_js()
    {
        # CSS
        wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css');
        wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
        wp_enqueue_style('liza-vc', get_template_directory_uri() . '/css/vc.css');
        wp_enqueue_style('liza-theme', get_template_directory_uri() . '/css/theme.css');
		if (liza_is_woocommerce_activated()) {
			wp_enqueue_style('liza-woocommerce', get_template_directory_uri() . '/css/woocommerce.css');
		}
		wp_enqueue_style('liza-responsive', get_template_directory_uri() . '/css/responsive.css');

        global $liza_custom_css;
        wp_add_inline_style('liza-theme', $liza_custom_css);

		if (get_post_type() == 'albums') {			
			wp_enqueue_style('liza-swipebox', get_template_directory_uri() . '/css/swipebox.css');
		}
		
        if (get_page_template_slug() == 'page-split-showcase.php') {
            wp_enqueue_style('liza-swipebox', get_template_directory_uri() . '/css/swipebox.css');
        } 

        # JS
		wp_enqueue_script('mousewheel_js', get_template_directory_uri() . '/js/jquery.mousewheel.js', array(), false, true);
        wp_enqueue_script('liza-theme', get_template_directory_uri() . '/js/theme.js', array('jquery'), false, true);
		if (liza_is_woocommerce_activated()) {
			wp_enqueue_script('liza-woocommerce', get_template_directory_uri() . '/js/woocommerce.js', array('jquery'), false, true);
		}
		if (get_post_type() == 'albums') {			
			wp_enqueue_script('jquery_swipebox', get_template_directory_uri() . '/js/jquery.swipebox.js', true, false, true);
		}		
		if (get_page_template_slug() == 'page-albums-slider.php') {
			wp_enqueue_script('pm_albums_slider', get_template_directory_uri() . '/js/pm_albums_slider.js', true, false, true);
			wp_enqueue_script('jquery-event-swipe', get_template_directory_uri() . '/js/jquery.event.swipe.js', array('jquery'), false, true);
		}
		if (get_page_template_slug() == 'page-albums-ajax-slider.php') {
			wp_enqueue_script('pm_albums_slider', get_template_directory_uri() . '/js/pm_albums_ajax_slider.js', true, false, true);
			wp_enqueue_script('jquery-event-swipe', get_template_directory_uri() . '/js/jquery.event.swipe.js', array('jquery'), false, true);			
		}

        wp_localize_script('liza-theme', 'liza_ajaxurl', 
            array(
                'url' => admin_url('admin-ajax.php')
            )
        ); 
    }
}

# Register CSS/JS for Admin Settings
add_action('admin_enqueue_scripts', 'liza_admin_css_js');
if (!function_exists('liza_admin_css_js')) {
    function liza_admin_css_js()
    {
        # CSS
        wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css');
        wp_enqueue_style('liza-admin', get_template_directory_uri() . '/css/admin.css');
        # JS
        wp_enqueue_script('liza-admin', get_template_directory_uri() . '/js/admin.js', array('jquery', 'jquery-ui-core', 'jquery-ui-sortable'), false, true);
    }
}

# WP Footer
add_action('wp_footer', 'liza_wp_footer');
function liza_wp_footer()
{
    lizaHelper::getInstance()->echoFooter();
}

# Register Menu
add_action('init', 'liza_register_menu');
function liza_register_menu()
{
    register_nav_menus(
        array(
            'main' => esc_attr__('Main menu', 'liza')
        )
    );
}

# Header
function liza_get_header()
{	
	$liza_main_menu_before = '';
	$liza_main_menu_after = '';
	$liza_main_menu_notify = '';
	$liza_social_icons = '';
	if (liza_get_prefered_option('social_icons') == 'show') {
		$liza_social_icons = '
			<div class="liza_social_icons liza_blur_on_aside">
				<ul class="liza_social_icons_list">
				'. 
					liza_show_social_icons(array(
						array(
							"uniqid" => "liza_soc_facebook",
							"class" => "facebook",
							"title" => "Facebook",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_twitter",
							"class" => "twitter",
							"title" => "Twitter",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_linkedin",
							"class" => "linkedin",
							"title" => "Linked In",
							"target" => "_blank",
						),						
						array(
							"uniqid" => "liza_soc_gplus",
							"class" => "google-plus",
							"title" => "Google+",
							"target" => "_blank",
						),						
						array(
							"uniqid" => "liza_soc_youtube",
							"class" => "youtube",
							"title" => "Youtube",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_instagram",
							"class" => "instagram",
							"title" => "Instagram",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_pinterest",
							"class" => "pinterest",
							"title" => "Pinterest",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_tumblr",
							"class" => "tumblr",
							"title" => "Tumblr",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_flickr",
							"class" => "flickr",
							"title" => "Flickr",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_vk",
							"class" => "vk",
							"title" => "VK",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_dribbble",
							"class" => "dribbble",
							"title" => "Dribbble",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_vimeo",
							"class" => "vimeo",
							"title" => "Vimeo",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_500px",
							"class" => "500px",
							"title" => "500px",
							"target" => "_blank",
						),
						array(
							"uniqid" => "liza_soc_litmind",
							"class" => "circle",
							"title" => "Litmind",
							"target" => "_blank",
						),
					));
                    # Shoping Cart
                    if (liza_is_woocommerce_activated() && liza_get_theme_mod('cart_in_header') == 'show') {
                        $liza_social_icons .= '
                            <li><a class="liza_shopping_cart" href="'. esc_js(wc_get_cart_url()) .'" data-items="'. WC()->cart->get_cart_contents_count() .'">
                                <i class="fa fa-shopping-cart"></i>
                            </a></li>
                        ';
                    }
        $liza_social_icons .= '
				</ul>
			</div>
		';
	}
	if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
		$liza_main_menu_before .= '<div class="liza_menu_block">';
		$liza_menu_locations = get_nav_menu_locations();
		if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
			if (liza_get_prefered_option('menu_style') == 'menu_aside' || liza_get_prefered_option('menu_style') == 'menu_simple') {
			$liza_main_menu_before .= '
				<a class="liza_menu_toggler" href="'. esc_js("javascript:void(0)") .'"><span class="liza_menu_ico"><span class="liza_menu_ico_line1"></span><span class="liza_menu_ico_line2"></span><span class="liza_menu_ico_line3"></span></span>'. esc_html__('Menu', 'liza') .'</a>';
				
			} else {
				
			}
			$liza_main_menu_after = '</div>';
		}
	}
	
	if (liza_get_prefered_option('logo_position') == 'logo_left') {
		if (liza_get_prefered_option('menu_style') == 'menu_aside') {
			echo '
			<div class="liza_header_left_part">';
			if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
				if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
					echo $liza_main_menu_before;
					echo $liza_main_menu_after;
				} else {
					echo '<div class="liza_blur_on_aside liza_menu_notify">' . esc_html__('Please create and select menu in Appearance (Menus)', 'liza') . ' <a href="'.get_admin_url(null, 'nav-menus.php').'"><i class="fa fa-long-arrow-right" aria-hidden="true"></i></a></div>';
				}
			}
					
			liza_the_logo();
			echo '</div>';
		} else {
			echo '
			<div class="liza_header_left_part">';
			liza_the_logo();
			if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
				if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
					echo $liza_main_menu_before;
					if (liza_get_prefered_option('menu_style') !== 'menu_aside') {
						echo '<nav class="liza_main_nav liza_blur_on_aside">';
						wp_nav_menu(array('theme_location' => 'main', 'menu_class' => 'liza_menu', 'depth' => '3'));
						echo '</nav>';
					}
					echo $liza_main_menu_after;
				} else {
					echo '<div class="liza_blur_on_aside liza_menu_notify">' . esc_html__('Please create and select menu in Appearance (Menus)', 'liza') . ' <a href="'.get_admin_url(null, 'nav-menus.php').'"><i class="fa fa-long-arrow-right" aria-hidden="true"></i></a></div>';
				}
			}			
			echo '</div>';
		}
		echo '
			<div class="liza_header_right_part">'. $liza_social_icons .'</div>
		';
	}
	if (liza_get_prefered_option('logo_position') == 'logo_right') {
		echo '
			<div class="liza_header_left_part">';
			if (liza_get_prefered_option('menu_style') == 'menu_simple') {
				echo $liza_social_icons;
			}
			if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
				if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
					echo $liza_main_menu_before;
					if (liza_get_prefered_option('menu_style') !== 'menu_aside') {
						echo '<nav class="liza_main_nav liza_blur_on_aside">';
						wp_nav_menu(array('theme_location' => 'main', 'menu_class' => 'liza_menu', 'depth' => '3'));
						echo '</nav>';
					}
					echo $liza_main_menu_after;
				} else {
					echo '<div class="liza_blur_on_aside liza_menu_notify">' . esc_html__('Please create and select menu in Appearance (Menus)', 'liza') . ' <a href="'.get_admin_url(null, 'nav-menus.php').'"><i class="fa fa-long-arrow-right" aria-hidden="true"></i></a></div>';
				}
			}
			if (liza_get_prefered_option('menu_style') !== 'menu_simple') {
				echo $liza_social_icons;
			}
		echo '
			</div>
			<div class="liza_header_right_part">';
			liza_the_logo();
		echo '</div>';
	}
	if (liza_get_prefered_option('logo_position') == 'logo_center') {
		echo '
			<div class="liza_header_left_part">';
				if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
					if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
						echo $liza_main_menu_before .'<nav class="liza_main_nav liza_blur_on_aside">';
						if (liza_get_prefered_option('menu_style') !== 'menu_aside') {
							wp_nav_menu(array('theme_location' => 'main', 'menu_class' => 'liza_menu', 'depth' => '3'));
						}
						echo '</nav>' . $liza_main_menu_after;
					} else {
						echo '<div class="liza_blur_on_aside liza_menu_notify">' . esc_html__('Please create and select menu in Appearance (Menus)', 'liza') . ' <a href="'.get_admin_url(null, 'nav-menus.php').'"><i class="fa fa-long-arrow-right" aria-hidden="true"></i></a></div>';
					}
				}			
		echo '
			</div>
			<div class="liza_header_middle_part">';
			liza_the_logo();
		echo '</div>
			<div class="liza_header_right_part">
				'. $liza_social_icons . '
			</div>';
	}
}

function liza_get_mobile_header() {
	$liza_menu_locations = get_nav_menu_locations();
	?>
    <header class="liza_mobile_header">
    	<div class="liza_mobile_header_wrapper">
        	<div class="liza_mobile_header_logo"><?php echo liza_the_logo(); ?></div>
            <div class="liza_mobile_button_wrapper">
            <?php
			if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
				if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
				?>
                <a class="liza_menu_toggler liza_menu_toggler_mobile" href="<?php echo esc_js("javascript:void(0)"); ?>"><span class="liza_menu_ico"><span class="liza_menu_ico_line1"></span><span class="liza_menu_ico_line2"></span><span class="liza_menu_ico_line3"></span></span><?php echo esc_html__('Menu', 'liza'); ?></a>                
                <?php
				} else {
					echo '<div class="liza_menu_notify liza_menu_notify_mobile">' . esc_html__('Please create and select menu in Appearance (Menus)', 'liza') . ' <a href="'.get_admin_url(null, 'nav-menus.php').'"><i class="fa fa-long-arrow-right" aria-hidden="true"></i></a></div>';
				}
			}
			?>
            </div>

        </div>
        <?php
			if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
				echo '<div class="liza_mobile_menu_wrapper">';
				if (liza_get_prefered_option('social_icons') == 'show') {
					echo '
						<div class="liza_social_icons liza_social_icons_mobile liza_container">
							<ul class="liza_social_icons_list">
							'. 
								liza_show_social_icons(array(
									array(
										"uniqid" => "liza_soc_facebook",
										"class" => "facebook",
										"title" => "Facebook",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_twitter",
										"class" => "twitter",
										"title" => "Twitter",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_linkedin",
										"class" => "linkedin",
										"title" => "Linked In",
										"target" => "_blank",
									),						
									array(
										"uniqid" => "liza_soc_gplus",
										"class" => "google-plus",
										"title" => "Google+",
										"target" => "_blank",
									),						
									array(
										"uniqid" => "liza_soc_youtube",
										"class" => "youtube",
										"title" => "Youtube",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_instagram",
										"class" => "instagram",
										"title" => "Instagram",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_pinterest",
										"class" => "pinterest",
										"title" => "Pinterest",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_tumblr",
										"class" => "tumblr",
										"title" => "Tumblr",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_flickr",
										"class" => "flickr",
										"title" => "Flickr",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_vk",
										"class" => "vk",
										"title" => "VK",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_dribbble",
										"class" => "dribbble",
										"title" => "Dribbble",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_vimeo",
										"class" => "vimeo",
										"title" => "Vimeo",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_500px",
										"class" => "500px",
										"title" => "500px",
										"target" => "_blank",
									),
									array(
										"uniqid" => "liza_soc_litmind",
										"class" => "circle",
										"title" => "Litmind",
										"target" => "_blank",
									),
								))
								.'
							</ul>
						</div>
					';
				}	
				if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
					echo '<nav class="liza_mobile_menu liza_container">';
							wp_nav_menu(array('theme_location' => 'main', 'menu_class' => 'liza_menu', 'depth' => '3'));
					echo '</nav>';
				}
				echo '</div><!-- .liza_mobile_menu_wrapper -->';
			}
		?>
    </header>
    <?php
}

# Aside Menu 
function liza_get_aside_menu() {
	if (liza_get_prefered_option('menu_style') == 'menu_aside') {
		if (liza_get_post_option('header_menu_status', 'show') !== 'hide') {
			$liza_menu_locations = get_nav_menu_locations();
			if (isset($liza_menu_locations['main']) && $liza_menu_locations['main'] !== 0) {
				?>
				<div class="liza_aside_menu_wrapper">
	                <a class="liza_menu_toggler" href="<?php echo esc_js("javascript:void(0)"); ?>">
                    	<span class="liza_menu_ico">
                        	<span class="liza_menu_ico_line1"></span>
                            <span class="liza_menu_ico_line2"></span>
                            <span class="liza_menu_ico_line3"></span>
						</span>
					</a>
                    <nav class="liza_main_nav">
                	<?php wp_nav_menu(array('theme_location' => 'main', 'menu_class' => 'liza_menu', 'depth' => '3', 'container' => '')); ?>
                    </nav>
					<div class="liza_aside_menu_share">
						<span class="liza_aside_menu_share_label"><?php echo esc_html__('Share', 'liza'); ?></span>
						<a target="_blank"
						   href="<?php echo esc_url('https://www.facebook.com/share.php?u='. get_permalink()); ?>" class="share_facebook">
						   <span class="fa fa-facebook"></span>
						</a>
						<a target="_blank"
						   href="<?php echo esc_url('https://twitter.com/intent/tweet?text='. get_the_title() .'&amp;url='. get_permalink()); ?>" class="share_twitter">
						   <span class="fa fa-twitter"></span>
						</a>
						<a target="_blank"
						   href="<?php echo esc_url('https://plus.google.com/share?url='. get_permalink()); ?>" class="share_gplus">
						   <span class="fa fa-google-plus"></span>
						</a>
						<a target="_blank"
						   href="<?php echo esc_url('https://pinterest.com/pin/create/button/?url='. get_permalink()); ?>" class="share_pinterest">
						   <span class="fa fa-pinterest"></span>
						</a>
					</div>
				</div>
			<?php
			}		
		}
	}
}

# Logo
function liza_the_logo($position = 'header')
{
	$liza_logo = '';
    if ($position == 'header') {
        $prefix = '';
    }
    if ($position == 'footer') {
        $prefix = 'footer_';
    }
	echo '<div class="liza_logo_wrapper liza_blur_on_aside">';
    if (liza_get_theme_mod(esc_attr($prefix) . 'logo_type') == 'image_logo') {
        echo '<a href="' . esc_url(home_url('/')) . '" class="liza_image_logo ' . (liza_get_theme_mod(esc_attr($prefix) . 'logo_retina') == true ? 'liza_retina' : '') . '"></a>';
    } else {
        echo '<div class="liza_text_logo"><a href="' . esc_url(home_url('/')) . '">' . liza_get_theme_mod(esc_attr($prefix) . 'logo_text_caption') . '</a></div>';
    }
	echo '</div>';
}

# Hex 2 RGB
function liza_HexToRGB($hex)
{
    $hex = str_replace("#", "", $hex);

    if (strlen($hex) == 3) {
        $r = hexdec(substr($hex, 0, 1) . substr($hex, 0, 1));
        $g = hexdec(substr($hex, 1, 1) . substr($hex, 1, 1));
        $b = hexdec(substr($hex, 2, 1) . substr($hex, 2, 1));
    } else {
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));
    }
    return $r . "," . $g . "," . $b;
}

# Register Sidebars
add_action('widgets_init', 'liza_widgets_init');
function liza_widgets_init()
{
    register_sidebar(
        array(
            'name' => esc_attr__('Sidebar', 'liza'),
            'id' => 'sidebar',
            'description' => esc_attr__('Widgets in this area will be shown on all posts and pages.', 'liza'),
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h5 class="widgettitle">',
            'after_title' => '</h5>',
        )
    );
    if (liza_is_woocommerce_activated()) {
        register_sidebar(
            array(
                'name' => esc_attr__('Sidebar Woocommerce', 'liza'),
                'id' => 'sidebar-woocommerce',
                'description' => esc_attr__('Widgets in this area will be shown on Woocommerce Pages.', 'liza'),
                'before_widget' => '<div id="%1$s" class="widget woocommerce_widget %2$s">',
                'after_widget' => '</div>',
                'before_title' => '<h6 class="widgettitle"><span>',
                'after_title' => '</span></h6>',
            )
        );
    }
}

# Post Formats
function liza_get_post_formats($args = array())
{
    if (liza_post_options()) {
        $html = '';
        if (!empty($args)) {
            extract($args);
            if (isset($output_template) && $output_template == 'blog_grid') {
                $grid_ratio = $grid_img_height / $grid_img_width;
            }
        }


        $html .= '<div class="liza_post_formats liza_pf_' . get_post_format() . '">';
        if (get_post_format() == 'image') {
            if (is_array(liza_get_post_option('liza_pf_images'))) {
                # CSS
                wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/css/owl.carousel.css');
                # JS
                wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), false, true);

                $html .= '<div class="liza_owlCarousel owl-carousel owl-theme">';
                foreach (liza_get_post_option('liza_pf_images') as $key => $image) {
                    if (isset($output_template) && $output_template == 'blog_grid') {
                        $html .= '<div class="item"><img src="' . aq_resize(esc_url($image['full_url']), esc_attr($grid_img_width), esc_attr($grid_img_height), true, true, true) . '" alt="' . esc_attr($image['alt']) . '"></div>';
                    } else if (isset($output_template) && $output_template == 'blog_masonry') {
						$html .= '<div class="item"><img src="' . aq_resize(esc_url($image['full_url']), esc_attr($grid_img_width), esc_attr($grid_img_height), true, true, true) . '" alt="' . esc_attr($image['alt']) . '"></div>';
					} else {
                        if (liza_get_post_option('liza_pf_images_crop_status', 'yes') == 'yes') {
                            $html .= '<div class="item"><img src="' . aq_resize(esc_url($image['full_url']), liza_get_post_option('liza_pf_images_width', '1600'), liza_get_post_option('liza_pf_images_height', '900'), true, true, true) . '" alt="' . esc_attr($image['alt']) . '"></div>';
                        } else {
                            $html .= '<div><img src="' . esc_url($image['full_url']) . '" alt="' . esc_attr($image['alt']) . '"></div>';
                        }
                    }
                }
                $html .= '</div>';

                lizaHelper::getInstance()->addJSToFooter('owl_post_formats', '
                    jQuery(".liza_owlCarousel").on("initialized.owl.carousel", function(e) {
						jQuery(".liza_owlCarousel").css("opacity", "1");
					});
					jQuery(".liza_owlCarousel").owlCarousel(
                        {
                            items:1,
						    lazyLoad:true,
							loop:true,
							autoplay:false,
							autoplayTimeout:5000,
							autoplayHoverPause:true,
							autoHeight:true
                        }
                    );
                ');
            } else {
                if (isset($output_template) && $output_template == 'blog_grid') {
                    $html .= '<img class="liza_stand_fi" src="' . aq_resize(liza_get_featured_image_url(), esc_attr($grid_img_width), esc_attr($grid_img_height)) . '" alt="">';
                } else {
                    $html .= '<img class="liza_stand_fi" src="' . aq_resize(liza_get_featured_image_url(), 300, 300) . '" alt="">';
                }
            }
        }

        if (get_post_format() == 'video') {
            if (isset($output_template) && $output_template == 'blog_masonry') {
                $html .= '<div class="liza_pf_video_cont liza_pf_video_16x9">' . liza_get_post_option('liza_pf_video_url') . '</div>';
            } else {
                $html .= '<div class="liza_pf_video_cont" style="height:' . liza_get_post_option('liza_pf_video_height', '500') . 'px;">' . liza_get_post_option('liza_pf_video_url') . '</div>';
            }
        }
        if (get_post_format() == 'audio') {
            if (isset($output_template) && $output_template == 'blog_grid') {
                $html .= '<div class="liza_pf_audio_cont liza_blog_grid_ratio" data-ratio="' . esc_attr($grid_ratio) . '">' . liza_get_post_option('liza_pf_audio_url') . '</div>';
            } else {
                $html .= '<div class="liza_pf_audio_cont">' . liza_get_post_option('liza_pf_audio_url') . '</div>';
            }
        }
        if (get_post_format() == 'quote') {
			$html .= '<div class="liza_pf_quote"><div class="liza_pf_quote_cont"><blockquote class="liza_pf_quote_text">' . liza_get_post_option('liza_pf_quote_text') . '</blockquote><h6 class="liza_pf_quote_author">' . liza_get_post_option('liza_pf_quote_author') . '</h6><div class="liza_pf_quote_additional">' . liza_get_post_option('liza_pf_quote_additional') . '</div></div></div>';
        }
        if (get_post_format() == '' && liza_get_featured_image_url()) {
			if (isset($output_template) && $output_template == 'blog_masonry') {
            	$html .= '<img class="liza_stand_fi" src="' . aq_resize(liza_get_featured_image_url(), esc_attr($grid_img_width), '', true, true, true) . '" alt="">';
			} else if (isset($output_template) && $output_template == 'projects_listing') {
				$html .= '<div class="liza_stand_fi_project_listing" data-src="' . aq_resize(liza_get_featured_image_url(), esc_attr($grid_img_width), esc_attr($grid_img_height), true, true, true) . '"><a href="' . get_permalink() . '" class="project_listing_see_btn">'. esc_html__('See The Project', 'liza') .'</a></div>';
			} else {
				$html .= '<img class="liza_stand_fi" src="' . liza_get_featured_image_url() . '" alt="">';
			}
        }
		
        $html .= '</div>';
        return $html;
    } else {
        return '<div class="liza_post_formats"><img class="liza_stand_fi" src="' . liza_get_featured_image_url() . '" alt=""></div>';
    }
}

# RWMB check
function liza_post_options()
{
    if (class_exists('RWMB_Loader')) {
        return true;
    } else {
        return false;
    }
}

# RWMB get option
function liza_get_post_option($name, $default = false)
{
    if (class_exists('RWMB_Loader')) {
        if (rwmb_meta($name)) {
            return rwmb_meta($name);
        } else {
            return $default;
        }
    } else {
        return $default;
    }
}

# Get Preffered Option
function liza_get_prefered_option($name)
{
	if (func_num_args() > 1) {
		die ('The liza_get_prefered_option("'.esc_attr($name).'") function may takes only one argument.');
	}
	
	global $liza_customizer_default_values;
	
	if (!isset($liza_customizer_default_values[$name])) {
		die ('Error! You did not add the default value for the "'.esc_attr($name).'" option! core/customizer.php.');
	}
	
    if (liza_get_post_option($name) && liza_get_post_option($name) !== 'default') {
        return liza_get_post_option($name, $liza_customizer_default_values[$name]);
    } else {
        return liza_get_theme_mod($name);
    }
}

# Previous and Next Posts
function liza_prev_next_posts()
{
    $prev_post = get_previous_post();
    $next_post = get_next_post();

    if (empty($prev_post) && empty($next_post)) {
        return;
    }

    global $post;

    echo '
        <div class="liza_prev_next_posts">
    ';

    echo '<div class="liza_prev_post">';

    if (!empty($prev_post)) {
        $post = get_post($prev_post->ID);
        setup_postdata($post);
		$image_block_html = '';
		$image_class = '';
		$liza_post_featured_image = liza_get_featured_image_url();
		if (!empty($liza_post_featured_image)) {
			$image_block_html = '
				<div class="liza_prev_post_img">
					<a href="' . get_permalink() . '"><img class="liza_stand_fi" src="' . aq_resize(liza_get_featured_image_url(), '160', '160', true, true, true) . '" alt=""></a>
				</div>			
			';
			$image_class = 'has_featured_image';
		}

        echo '
                    <div class="innerpadding '. $image_class .'">
						'. $image_block_html .'
						<div class="liza_prev_post_content">
							<a class="liza_prev_link" href="' . get_permalink() . '">'. esc_attr__('Previous Post', 'liza') .'</a>
							<div class="clear"></div>
							<a class="notextdecor liza_post_title" href="' . get_permalink() . '">
								<h6 class="innertitle">' . get_the_title() . '</h6>
							</a>							
						</div>
                    </div>
                ';

        wp_reset_postdata();
    }

    echo '</div>';
    echo '<div class="liza_next_post">';

    if (!empty($next_post)) {
        $post = get_post($next_post->ID);
        setup_postdata($post);
		$image_block_html = '';
		$image_class = '';
		$liza_post_featured_image = liza_get_featured_image_url();
		if (!empty($liza_post_featured_image)) {
			$image_block_html = '
				<div class="liza_next_post_img">
					<a href="' . get_permalink() . '"><img class="liza_stand_fi" src="' . aq_resize(liza_get_featured_image_url(), '160', '160', true, true, true) . '" alt=""></a>
				</div>			
			';
			$image_class = 'has_featured_image';
		}
        echo '
                
				<div class="innerpadding '. $image_class .'">
					<div class="liza_next_post_content">
						<a class="liza_next_link" href="' . get_permalink() . '">'. esc_attr__('Next Post', 'liza') .'</a>
						<div class="clear"></div>
						<a class="notextdecor liza_post_title" href="' . get_permalink() . '">
							<h6 class="innertitle">' . get_the_title() . '</h6>
						</a>							
					</div>
					'. $image_block_html .'
				</div>
		';

        wp_reset_postdata();
    }

    echo '
			</div>
        </div>
    ';
}

# Get Featured Image Url
function liza_get_featured_image_url()
{
    $featured_image_full_url = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
    if (isset($featured_image_full_url[0]) && strlen($featured_image_full_url[0]) > 0) {
        return esc_url($featured_image_full_url[0]);
    } else {
        return false;
    }
}

# Featured Posts
function liza_featured_posts($args = array('post_type' => 'post', 'orderby' => 'rand', 'numberposts' => '2', 'featured_image' => 'show', 'excerpt' => 'show', 'post_meta' => 'show', 'title' => 'show'))
{
    extract($args);

	$args = array(
		'post_type' => esc_attr($post_type),
		'post_status' => 'publish',
		'ignore_sticky_posts' => 1,
		'orderby' => esc_attr($orderby),
		'posts_per_page' => absint($numberposts),
	);

	query_posts($args);

	if (have_posts()) {
		if ($title == 'show') {
			echo '<h4 class="liza_tac liza_featured_posts_title">' . esc_attr__('Related Posts', 'liza') . '</h4>';
		}
		echo '<div class="row liza_featured_posts">';

		while (have_posts()) {
			the_post();
			?>

			<div class="col-md-<?php echo(12 / $numberposts); ?>">
				<?php if (liza_get_featured_image_url() && $featured_image == 'show') { ?>
					<a href="<?php the_permalink(); ?>" class="liza_fimage liza_image_fader">
						<img
							src="<?php echo aq_resize(liza_get_featured_image_url(), 800, 600, true, true, true); ?>"
							alt="">
					</a>
				<?php } ?>
				<a class="notextdecor liza_post_title" href="<?php the_permalink(); ?>">
					<h5 class="innertitle"><?php the_title(); ?></h5>
				</a>

				<?php if ($post_meta == 'show') { ?>
					<div class="liza_meta">
						<div><?php echo get_the_date(); ?></div>
						<div><?php echo esc_attr__('by', 'liza');
							echo ' ';
							the_author_posts_link(); ?></div>
						<div><?php echo esc_attr__('in', 'liza');
							echo ' ';
							if (!isset($post_type) || $post_type == 'post') {
								the_category(', ');
							}
							if (isset($post_type) && $post_type == 'project') {
								$projectCateg = '';
								$new_term_list = get_the_terms(get_the_id(), "projectcat");
								if (is_array($new_term_list)) {
									foreach ($new_term_list as $term) {
										$tempname = strtr($term->name, array(
											' ' => '-',
										));
										$projectCateg .= $tempname . ", ";
									}
								} else {
									$projectCateg = 'Uncategorized  ';
								}
								$projectCateg = substr($projectCateg, 0, -2);
								echo $projectCateg;
							}
							?>
						</div>
					</div>
				<?php } ?>
				<?php if ($excerpt == 'show') { ?>
					<div class="liza_excerpt">
						<?php the_excerpt(); ?>
					</div>
				<?php } ?>
			</div>
			<?php
		}
		wp_reset_query();

		echo '</div>';
	}
}

# Featured Albums
function liza_featured_albums($args = array('orderby' => 'rand', 'numberposts' => '2', 'featured_image' => 'show'))
{
    extract($args);

    if (liza_get_prefered_option('featured_posts_status') == 'enabled') {

        $args = array(
            'post_type' => 'albums',
            'post_status' => 'publish',
            'orderby' => esc_attr($orderby),
            'posts_per_page' => absint($numberposts),
        );

        query_posts($args);

        if (have_posts()) {

            echo '<h3 class="liza_tac liza_tac_albums">' . esc_attr__('You May Also Like', 'liza') . '</h3>';
            echo '<div class="row liza_featured_albums">';

            while (have_posts()) {
                the_post();
                ?>

                <div class="liza_featured_albums_col col-md-<?php echo(12 / esc_attr($numberposts)); ?>">
                	<div class="liza_featured_albums_item">
						<?php if (liza_get_featured_image_url() && $featured_image == 'show') { ?>
                            <a href="<?php the_permalink(); ?>" class="liza_featured_albums_image liza_image_fader">
                                <img
                                    src="<?php echo aq_resize(liza_get_featured_image_url(), 915, 600, true, true, true); ?>"
                                    alt="">
                            </a>
                        <?php } 
							$galCateg = '';
							$new_term_list = get_the_terms(get_the_id(), "albumscat");
							if (is_array($new_term_list)) {
								foreach ($new_term_list as $term) {
									$tempname = strtr($term->name, array(
										' ' => '-',
									));
									$galCateg .= $tempname . " / ";
								}
							} else {
								$galCateg = 'Uncategorized  ';
							}
							$galCateg = substr($galCateg, 0, -2);						
						?>
                        <div class="liza_features_albums_content">
                            <a class="liza_features_albums_title" href="<?php the_permalink(); ?>">
                                <h5 class="innertitle"><?php the_title(); ?></h5>
                            </a>
                            <div class="liza_featured_albums_meta">
                            	<?php echo esc_attr($galCateg); ?>
                            </div>
                        </div>    
                    </div>
                </div>
                <?php
            }
            wp_reset_query();

            echo '</div>';
        }
    }
}

# Transparent Header Check
function liza_transparent_header_check()
{
    if (!is_404()) {
        if (liza_get_prefered_option('header_transparent') == 'enabled') {
            lizaHelper::getInstance()->addJSToFooter('transp_head', '
        jQuery("html").addClass("liza_transparent_header");
    ');
        } else {
            lizaHelper::getInstance()->addJSToFooter('non_transp_head', '
        jQuery("html").addClass("liza_non_transparent_header");
    ');
        }
    }
}
function liza_content_under_header_check() {
    if (!is_404()) {
        if (liza_get_post_option('content_under_header', 'disabled') == 'enabled') {
            lizaHelper::getInstance()->addJSToFooter('content_under_header', '
				jQuery("html").addClass("liza_content_under_header");
				liza_push_content_under_header();
    		');
        }
    }	
}
	
# VC Init
add_action('vc_before_init', 'liza_vc_before_init_actions');
function liza_vc_before_init_actions()
{
    setcookie('vchideactivationmsg', '1', strtotime('+3 years'), '/');
    setcookie('vchideactivationmsg_vc11', (defined('WPB_VC_VERSION') ? WPB_VC_VERSION : '1'), strtotime('+3 years'), '/');
    vc_set_as_theme();

	require_once(get_template_directory() . '/core/vc-elements/albums_grid/albums_grid.php');
	require_once(get_template_directory() . '/core/vc-elements/blog/blog.php');
    require_once(get_template_directory() . '/core/vc-elements/blog_grid/blog_grid.php');
	require_once(get_template_directory() . '/core/vc-elements/related_posts/related_posts.php');
	require_once(get_template_directory() . '/core/vc-elements/button/button.php');
    require_once(get_template_directory() . '/core/vc-elements/grid_gallery/grid_gallery.php');
	require_once(get_template_directory() . '/core/vc-elements/gallery_ribbon/gallery_ribbon.php');
    require_once(get_template_directory() . '/core/vc-elements/counter/counter.php');
	require_once(get_template_directory() . '/core/vc-elements/image_carousel/image_carousel.php');
	require_once(get_template_directory() . '/core/vc-elements/projects/projects.php');
	require_once(get_template_directory() . '/core/vc-elements/projects_grid/projects_grid.php');
    require_once(get_template_directory() . '/core/vc-elements/price_table/price_table.php');
	require_once(get_template_directory() . '/core/vc-elements/promo_block/promo_block.php');
	require_once(get_template_directory() . '/core/vc-elements/skills/skills.php');
    require_once(get_template_directory() . '/core/vc-elements/testimonials/testimonials.php');
	require_once(get_template_directory() . '/core/vc-elements/testimonials_flow/testimonials_flow.php');
    require_once(get_template_directory() . '/core/vc-elements/promo_text/promo_text.php');
    require_once(get_template_directory() . '/core/vc-elements/stripes/stripes.php');
    require_once(get_template_directory() . '/core/vc-elements/simple_slider/simple_slider.php');
	
	require_once(get_template_directory() . '/core/vc-tools/pm_albums.php');
	require_once(get_template_directory() . '/core/vc-tools/pm_categories.php');
	require_once(get_template_directory() . '/core/vc-tools/pm_categories_filter.php');
}

# PRE
function liza_pre($array)
{
    echo '<pre>';
    print_r($array);
    echo '</pre>';
}

# Get Image Meta
function liza_get_attachment($attachment_id)
{
    $attachment = get_post($attachment_id);
    return array(
        'alt' => get_post_meta($attachment->ID, '_wp_attachment_image_alt', true),
        'caption' => $attachment->post_excerpt,
        'description' => $attachment->post_content,
        'href' => get_permalink($attachment->ID),
        'src' => $attachment->guid,
        'title' => $attachment->post_title
    );
}

add_filter('admin_footer', 'liza_admin_footer');
function liza_admin_footer()
{
	if (strlen(get_page_template_slug())>0) {
    	echo "<input type='hidden' name='' value='" . (get_page_template_slug() ? get_page_template_slug() : '') . "' class='liza_this_template_file'>";
    }
}

# Admin_Head
add_action('admin_head', 'liza_admin_head');
function liza_admin_head()
{
    echo "
    <script type='text/javascript'>
    var liza_themeurl = '" . esc_url(get_template_directory_uri()) . "';
    </script>";
}

# Tiny Dropcap Button
add_editor_style('css/core/pm_tiny.css');
add_action('init', 'liza_tiny');
function liza_tiny()
{
    if (current_user_can('edit_posts') && current_user_can('edit_pages')) {
        add_filter('mce_external_plugins', 'liza_tiny_plugin');
        add_filter('mce_buttons', 'liza_tiny_register_button');
    }
}

function liza_tiny_plugin($plugin_array)
{
    $plugin_array['liza_tiny'] = esc_url(get_template_directory_uri()) . '/js/core/pm_tiny.js';
    return $plugin_array;
}

function liza_tiny_register_button($buttons)
{
    array_push($buttons, "liza_dropcap");
    return $buttons;
}

add_filter('mce_buttons_2', 'liza_mce_buttons_2');
function liza_mce_buttons_2($buttons)
{
    array_push($buttons, 'backcolor');
    return $buttons;
}

add_filter('preview_post_link', 'liza_remove_post_format_parameter', 9999);
function liza_remove_post_format_parameter($url) {
    $url = remove_query_arg('post_format', $url);
    return $url;
}

add_filter('wp_list_categories', 'liza_category_filter');
function liza_category_filter($links) {
  $links = str_replace('</a> (', ' (', $links);
  $links = str_replace(')', ')</a>', $links);
  return $links;
}

if (!function_exists('liza_HexToRGB')) {
    function liza_HexToRGB($hex = "#ffffff")
    {
        $color = array();
        if (strlen($hex) < 1) {
            $hex = "#ffffff";
        }

        $color['r'] = hexdec(substr($hex, 1, 2));
        $color['g'] = hexdec(substr($hex, 3, 2));
        $color['b'] = hexdec(substr($hex, 5, 2));

        return $color['r'] . "," . $color['g'] . "," . $color['b'];
    }
}

# Object to array
function liza_objectToArray($object) {
    if(!is_object($object) && !is_array($object))
        return $object;

    return array_map('liza_objectToArray', (array) $object);
}

# Breadcrumb
function liza_get_breadcrumb() {
	if (liza_get_prefered_option('breadcrumb_state') == 'on' || liza_get_post_option('single_page_title', 'show') == 'show') {
		$breadcrumb_img_src = '';
		$breadcrumb_null_class = '';
		if (is_array(liza_get_prefered_option('breadcrumb_bg_image'))) {
			foreach (liza_get_prefered_option('breadcrumb_bg_image') as $key => $image) {
				$breadcrumb_img_src = $image['full_url'];
			}
		} else {
			$breadcrumb_img_src = liza_get_prefered_option('breadcrumb_bg_image');
		}
		if (liza_is_woocommerce_activated() && is_woocommerce() && is_product()) {
			$attachment_id = get_post_thumbnail_id();
			$attachment = wp_get_attachment_image_src($attachment_id, 'full' )[0];
			if (!empty($attachment) && $attachment !== '') {
				$breadcrumb_img_src = $attachment;
			} else {
				$breadcrumb_img_src = liza_get_prefered_option('breadcrumb_bg_image');
			}
		}
		if(stristr($breadcrumb_img_src, 'null.png')) {
			$breadcrumb_null_class = 'liza_null_bread_bg';
		}
		?>
		<div class="liza_title_breadcrumb_wrapper liza_blur_on_aside liza_js_bg_image <?php echo esc_attr($breadcrumb_null_class); ?>" data-src="<?php echo esc_url($breadcrumb_img_src); ?>">
        	<div class="liza_title_breadcrumb_inner liza_container">
				<?php if (liza_is_woocommerce_activated() && is_woocommerce()) {
					echo '<div class="liza_title"><h1 class="entry-title">';
					if (is_shop() || is_product_taxonomy() || is_product_tag() || is_product_category()) {
						woocommerce_page_title();
					} else {
						the_title();
					}
					echo '</h1></div>';
					add_filter('woocommerce_show_page_title', '__return_false');
				} else {
					if (liza_get_post_option('single_page_title', 'show') == 'show') { ?>
					<div class="liza_title">
						<h1 class="entry-title"><?php the_title(); ?></h1>
					</div>
				<?php }	
				}
				if (liza_get_prefered_option('breadcrumb_state') == 'on') {
					$showOnHome = 0;
					$delimiter = '<span class="liza_breadcrumb_divider">/</span>';
					$home = esc_html__('Home', 'liza');
					$showCurrent = 1;
					$before = '<span class="current">';
					$after = '</span>';
					global $post;
					$homeLink = esc_url(home_url('/'));
					if (is_home() || is_front_page()) {
						if ($showOnHome == 1) echo '<div class="liza_breadcrumbs"><span>' . esc_attr($home) . '</span></div>';
					} else {
				
						echo '<div class="liza_breadcrumbs"><a href="' . esc_url($homeLink) . '">' . esc_attr($home) . '</a>' . $delimiter . '';
						if (is_category()) {
							$thisCat = get_category(get_query_var('cat'), false);
							if ($thisCat->parent != 0) echo get_category_parents($thisCat->parent, TRUE, ' ' . $delimiter . ' ');
							echo $before . 'Archive "' . single_cat_title('', false) . '"' . $after;
				
						}
						elseif (get_post_type() == 'project') {
				
							the_terms($post->ID, 'projectcat', '', ', ', '');
				
							if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
				
						} elseif (is_search()) {
							echo $before . 'Search for "' . get_search_query() . '"' . $after;
				
						} elseif (is_day()) {
							echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
							echo '<a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
							echo $before . get_the_time('d') . $after;
				
						} elseif (is_month()) {
							echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
							echo $before . get_the_time('F') . $after;
				
						} elseif (is_year()) {
							echo $before . get_the_time('Y') . $after;
				
						} elseif (is_single() && !is_attachment()) {
							if (get_post_type() != 'post') {
				
								$parent_id = $post->post_parent;
								if ($parent_id > 0) {
									$breadcrumbs = array();
									while ($parent_id) {
										$page = get_page($parent_id);
										$breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
										$parent_id = $page->post_parent;
									}
									$breadcrumbs = array_reverse($breadcrumbs);
									for ($i = 0; $i < count($breadcrumbs); $i++) {
										echo $breadcrumbs[$i];
										if ($i != count($breadcrumbs) - 1) echo ' ' . $delimiter . ' ';
									}
									if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
								} else {
									echo $before . get_the_title() . $after;
								}
				
							} else {
								$cat = get_the_category();
								$cat = $cat[0];
								$cats = get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
								if ($showCurrent == 0) $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
								echo $cats;
								if ($showCurrent == 1) echo $before . get_the_title() . $after;
							}
				
						} elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404() && !is_woocommerce()) {
							$post_type = get_post_type_object(get_post_type());
							echo $before . $post_type->labels->singular_name . $after;
						} elseif (liza_is_woocommerce_activated()) {
                            if (is_woocommerce()) {
                                $args = array(
                                    'delimiter' => '<span class="liza_breadcrumb_divider">/</span>',
                                    'home' => false
                                );
                                woocommerce_breadcrumb($args);
                            } else {
                                if (is_page() && !$post->post_parent) {
                                    if ($showCurrent == 1) echo $before . get_the_title() . $after;
                                } elseif (is_page() && $post->post_parent) {
                                    $parent_id = $post->post_parent;
                                    $breadcrumbs = array();
                                    while ($parent_id) {
                                        $page = get_page($parent_id);
                                        $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
                                        $parent_id = $page->post_parent;
                                    }
                                    $breadcrumbs = array_reverse($breadcrumbs);
                                    for ($i = 0; $i < count($breadcrumbs); $i++) {
                                        echo $breadcrumbs[$i];
                                        if ($i != count($breadcrumbs) - 1) echo ' ' . $delimiter . ' ';
                                    }
                                    if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
                                }
                            }
						} elseif (is_attachment()) {
							$parent = get_post($post->post_parent);
							$cat = get_the_category($parent->ID);
                            if (!empty($cat)) {
                                $cat = $cat[0];
                                echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
                            }
							echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a>';
							if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
				
						} elseif (is_page() && !$post->post_parent) {
							if ($showCurrent == 1) echo $before . get_the_title() . $after;
				
						} elseif (is_page() && $post->post_parent) {
							$parent_id = $post->post_parent;
							$breadcrumbs = array();
							while ($parent_id) {
								$page = get_page($parent_id);
								$breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
								$parent_id = $page->post_parent;
							}
							$breadcrumbs = array_reverse($breadcrumbs);
							for ($i = 0; $i < count($breadcrumbs); $i++) {
								echo $breadcrumbs[$i];
								if ($i != count($breadcrumbs) - 1) echo ' ' . $delimiter . ' ';
							}
							if ($showCurrent == 1) echo ' ' . $delimiter . ' ' . $before . get_the_title() . $after;
				
						} elseif (is_tag()) {
							echo $before . 'Tag "' . single_tag_title('', false) . '"' . $after;
				
						} elseif (is_author()) {
							global $author;
							$userdata = get_userdata($author);
							echo $before . esc_html__('Author', 'liza') . ' ' . $userdata->display_name . $after;
				
						} elseif (is_404()) {
							echo $before . esc_html__('Error 404', 'liza') . $after;
						}
				
						echo '</div>';
				
					}					
				} ?>
			</div>
        </div>
        <?php
	}
}

function add_pm_code($name, $callback, $filename)  {
	$short = 'code_param';
	if (empty($filename)) {
		call_user_func('vc_add_short' . $short, $name, $callback);
	} else{
		call_user_func('vc_add_short' . $short, $name, $callback, $filename);
	}
}

# Posts Isotope Filter
if (!function_exists('liza_show_filter')) {
    function liza_show_filter($post_type_terms = "", $post_type = "", $show_all = "yes", $active = "all")
    {
		if (!isset($show_all))
			$show_all = 'yes';
		if (!isset($active))
			$active = "all";
        if (!isset($term_list)) {
            $term_list = '';
        }
		$active_class = '';
		$active_data = '';
		if ($active !== '' && $active !== 'all') {
			$active_class = 'activate_custom_filter';
			$active_data = 'data-active="'. $active .'"';
		}
        $permalink = get_permalink();
        $args = array('taxonomy' => 'Category', 'field' => 'slug', 'include' => $post_type_terms);
        $terms = get_terms($post_type . 'cat', $args);
        $count = count($terms);
        $i = 0;
        $iterm = 1;
        if ($count > 0) {
            $cape_list = '';
            if ($count > 1 && $show_all == 'yes') {
                $term_list .= '<li class="' . (!isset($_GET['slug']) ? 'selected' : '') . '">';

                $term_list .= '<a href="' . esc_url($permalink) . '" data-option-value="*">' . esc_html__('All', 'liza') . '</a>
			</li>';
            }
            $termcount = count($terms);
            if (is_array($terms)) {
                foreach ($terms as $term) { 
                    $i++;
                    $permalink = esc_url(add_query_arg("slug", $term->slug, $permalink));
                    $term_list .= '<li ';
                    if (isset($_GET['slug'])) {
                        $getslug = $_GET['slug'];
                    } else {
                        $getslug = '';
                    }

                    if ($count == 1) {
                        $term_list .= 'class="selected"';
                    } else {
                        if (strnatcasecmp($getslug, $term->slug) == 0) $term_list .= 'class="selected"';
                    }

                    $tempname = strtr($term->name, array(
                        ' ' => '-',
						'+' => '-'
                    ));
                    $tempname = strtolower($tempname);
                    $term_list .= '><a data-option-value=".' . esc_attr($tempname) . '" class="' . esc_attr($tempname) . '" href="' . esc_url($permalink) . '" title="' . esc_html__('View all post filed under', 'liza') . ' ">' . $term->name . '</a>
                </li>';
                    if ($count != $i) $term_list .= ' '; else $term_list .= '';

                    $iterm++;
                }
            }
            return '<div class="liza_filter_block"><ul id="options"><li><ul class="liza_'. esc_attr($post_type) .'_optionset liza_filter_inner '. $active_class .'" data-option-key="filter" '. $active_data .'>' . $term_list . '</ul></li></ul></div>';
        }
    }
}

/* Social Icons */
if (!function_exists('liza_show_social_icons')) {
	function liza_show_social_icons($array)
	{
		$compile = "";
		foreach ($array as $key => $value) {
			if (strlen(liza_get_theme_mod($value['uniqid'])) > 0) {
				$compile .= "<li><a class='" . esc_attr($value['class']) . "' target='" . esc_attr($value['target']) . "' href='" . esc_url(liza_get_theme_mod($value['uniqid'])) . "' title='" . esc_attr($value['title']) . "'><i class='fa fa-" . esc_attr($value['class']) . "'></i></a></li>";
			}
		}
		$compile .= "";
		if (is_array($array) && count($array) > 0) {
			return $compile;
		} else {
			return "";
		}
	}
}

/* Social Links */
if (!function_exists('liza_show_social_links')) {
	function liza_show_social_links($array)
	{
		$compile = "";
		foreach ($array as $key => $value) {
			if (strlen(liza_get_theme_mod($value['uniqid'])) > 0) {
				$compile .= "<a class='" . esc_attr($value['class']) . "' target='" . esc_attr($value['target']) . "' href='" . esc_url(liza_get_theme_mod($value['uniqid'])) . "' title='" . esc_attr($value['title']) . "'><i class='fa fa-" . esc_attr($value['class']) . "'></i></a>";
			}
		}
		$compile .= "";
		if (is_array($array) && count($array) > 0) {
			return $compile;
		} else {
			return "";
		}
	}
}

# Activate Visual Composer for Custom Post Types
$list = array(
    'page',
	'post',
	'project'
);
if (function_exists('vc_set_default_editor_post_types')) {
	vc_set_default_editor_post_types($list);
}

if (!function_exists( 'liza_is_woocommerce_activated')) {
	function liza_is_woocommerce_activated() {
		return class_exists( 'WooCommerce' ) ? true : false;
	}
}

if (liza_is_woocommerce_activated()) {
    add_action('customize_register', 'liza_shop_customizer_register');
    function liza_shop_customizer_register($wp_customize) {        
        global $liza_customizer_default_values;
        
        $wp_customize->add_section('liza_shop_settings',
            array(
                'title' => esc_attr__('Liza Shop Settings', 'liza'),
                'panel' => 'woocommerce',
            )
        );
        $wp_customize->add_section('liza_shop_colors',
            array(
                'title' => esc_attr__('Additional Shop Colors', 'liza'),
                'panel' => 'woocommerce',
            )
        );

        # Sidebar Position
        $wp_setting_name = 'shop_sidebar_position';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Sidebar Position', 'liza'),
                'section' => 'liza_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('liza_left_sidebar' => 'Left', 'liza_right_sidebar' => 'Right', 'liza_no_sidebar' => 'None'),
            )
        ));
        
        # Sale Label
        $wp_setting_name = 'shop_sale_label';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Sale Label State', 'liza'),
                'section' => 'liza_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));
        
        # Header Cart
        $wp_setting_name = 'cart_in_header';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Cart Icon in Header', 'liza'),
                'section' => 'liza_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('show' => 'Show', ' hide' => 'Hide'),
            )
        ));
        
        # Product Lightbox
        $wp_setting_name = 'shop_lightbox';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Single Product Image Lightbox', 'liza'),
                'section' => 'liza_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));
        
        # Product Zoom
        $wp_setting_name = 'shop_zoom';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Single Product Image Zoom', 'liza'),
                'section' => 'liza_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));
        
        # Product Slider
        $wp_setting_name = 'shop_slider';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Single Product Image Slider', 'liza'),
                'section' => 'liza_shop_settings',
                'settings' => $wp_setting_name,
                'type' => 'select',
                'choices' => array('on' => 'On', 'off' => 'Off'),
            )
        ));
        
        # Shop Color Message
        $wp_setting_name = 'shop_color_message';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Color_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Message Box Color', 'liza'),
                'section' => 'liza_shop_colors',
                'settings' => $wp_setting_name,
            )
        ));

        # Shop Color Info
        $wp_setting_name = 'shop_color_info';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Color_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Info Box Color', 'liza'),
                'section' => 'liza_shop_colors',
                'settings' => $wp_setting_name,
            )
        ));

        # Shop Color Error
        $wp_setting_name = 'shop_color_error';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Color_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Error Box Color', 'liza'),
                'section' => 'liza_shop_colors',
                'settings' => $wp_setting_name,
            )
        ));

        # Shop Color Required
        $wp_setting_name = 'shop_color_required';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Color_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Required Fields Color', 'liza'),
                'section' => 'liza_shop_colors',
                'settings' => $wp_setting_name,
            )
        ));

        # Shop Color Remove
        $wp_setting_name = 'shop_color_remove';
        $wp_customize->add_setting($wp_setting_name, array('default' => $liza_customizer_default_values[$wp_setting_name], 'sanitize_callback'	=> 'esc_attr'));
        $wp_customize->add_control(new WP_Customize_Color_Control(
            $wp_customize,
            $wp_setting_name,
            array(
                'label' => esc_attr__('Remove Cross Color', 'liza'),
                'section' => 'liza_shop_colors',
                'settings' => $wp_setting_name,
            )
        ));

    }
}

if (class_exists('WooCommerce')) {
    add_theme_support( 'woocommerce', array(
        'thumbnail_image_width' => 500,
        'thumbnail_image_height' => 500,
        'single_image_width'    => 640,
        'product_grid'          => array(
            'default_rows'    => 3,
            'min_rows'        => 2,
            'max_rows'        => 8,
            'default_columns' => 3,
            'min_columns'     => 2,
            'max_columns'     => 5,
        ),
    ));
    if (liza_get_theme_mod('shop_zoom') == 'on') {
        add_theme_support( 'wc-product-gallery-zoom' );
    }
    if (liza_get_theme_mod('shop_lightbox') == 'on') {
        add_theme_support( 'wc-product-gallery-lightbox' );
    }
    if (liza_get_theme_mod('shop_slider') == 'on') {
        add_theme_support( 'wc-product-gallery-slider' );
    }
}

function liza_add_template_slug_to_body( $classes ) {
	$templateName = basename(get_page_template_slug(get_the_ID()));
	$templateName = str_ireplace('template-', '', basename(get_page_template_slug(get_the_ID()), '.php'));

	$pf = get_post_format(get_the_ID());
	$post_type = get_post_format(get_the_ID());
	$post_type_class = '';
	
	if (!empty($post_type)) {
		$post_type_class = ' post-type-' . get_post_format();
	}
	
    return $classes . $templateName . $post_type_class;
}
add_filter('admin_body_class', 'liza_add_template_slug_to_body');